/***************************************************************************
 *   Copyright (C) 2004 by Rick L. Vinyard, Jr.                            *
 *   rvinyard@cs.nmsu.edu                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU Lesser General Public License as        *
 *   published by the Free Software Foundation version 2.1.                *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU Lesser General Public      *
 *   License along with this library; if not, write to the                 *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA              *
 ***************************************************************************/
#ifndef PAPYRUSGRID_H
#define PAPYRUSGRID_H

#include <papyrus/drawable.h>
#include <papyrus/linestyle.h>
#include <papyrus/enums.h>

namespace Papyrus
{

  /**
        @author Rick L Vinyard Jr <rvinyard@cs.nmsu.edu>
  */
  class Grid : public Drawable
  {
    public:
      typedef PapyrusSmartPointer<Grid> pointer;

      static const double infinity;

      Grid(double xmin=-infinity, double xmax=infinity,
           double ymin=-infinity, double ymax=infinity);

      static pointer create(double xmin=-infinity, double xmax=infinity,
                            double ymin=-infinity, double ymax=infinity);

      virtual ~Grid();

      double x_min();

      void set_x_min( double min );

      double x_max();

      void set_x_max( double max );

      void x_min_max( double& min, double& max );

      void set_x_min_max( double min, double max );

      double y_min();

      void set_y_min( double min );

      double y_max();

      void set_y_max( double max );

      void y_min_max( double& min, double& max );

      void set_y_min_max( double min, double max );

      void xy_min_max( double& x_min, double& x_max, double& y_min, double& y_max );

      void set_xy_min_max( double x_min, double x_max, double y_min, double y_max );

      void enable_axis( unsigned which = X_AXIS | Y_AXIS );

      void disable_axis( unsigned which = X_AXIS | Y_AXIS );

      const LineStyle& x_axis_style() const;

      void set_x_axis_style( const LineStyle& style );

      const LineStyle& y_axis_style() const;

      void set_y_axis_style( const LineStyle& style );

      void set_xy_axis_style( const LineStyle& style );

      void enable_border( unsigned which = TOP | RIGHT | BOTTOM | LEFT );

      void disable_border( unsigned which = TOP | RIGHT | BOTTOM | LEFT );

      void set_border_style( const LineStyle& style,
                             unsigned which = TOP | RIGHT | BOTTOM | LEFT );

      double x_interval();

      void set_x_interval( double x_interval );

      const LineStyle& x_interval_style();

      void set_x_interval_style( const LineStyle& );

      double y_interval();

      void set_y_interval( double y_interval );

      const LineStyle& y_interval_style();

      void set_y_interval_style( const LineStyle& );

      void xy_interval( double& x_interval, double& y_interval );

      void set_xy_interval( double interval );

      void set_xy_interval( double x_interval, double y_interval );

      void xy_interval_style( LineStyle& x_style, LineStyle& y_style );

      void set_xy_interval_style( const LineStyle& style );

      void set_xy_interval_style( const LineStyle& x_style, const LineStyle& y_style );

      /** Draws on the provided context */
      virtual void draw( Cairo::RefPtr<Cairo::Context> cairo );

      PAPYRUS_CLONE_METHOD( Grid );

    protected:
      LineStyle m_x_axis_style,
      m_y_axis_style,
      m_x_interval_style,
      m_y_interval_style,
      m_border_style[ 4 ];
      double m_x_min, m_x_max, m_y_min, m_y_max;
      double m_x_interval, m_y_interval;
      unsigned int m_enabled_axes, m_enabled_borders;

  };

}

#endif
