/***************************************************************************
 *   Copyright (C) 2004 by Rick L. Vinyard, Jr.                            *
 *   rvinyard@cs.nmsu.edu                                                  *
 *                                                                         *
 *   Copyright (C) 2007 Peter Miller                                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU Lesser General Public License as        *
 *   published by the Free Software Foundation version 2.1.                *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU Lesser General Public      *
 *   License along with this library; if not, write to the                 *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA              *
 ***************************************************************************/
#ifndef PAPYRUSIMAGE_H
#define PAPYRUSIMAGE_H

#include <papyrus/drawable.h>

namespace Papyrus
{

  /**
   * The Image class is used to represent an image to be drawn into
   * the canvas.  It can be scaled and transformed just like any other
   * drawable.
   *
   * @author Rick L Vinyard Jr
   */
  class Image : public Drawable
  {
    public:
      typedef PapyrusSmartPointer< Image > pointer;

      Image();

      Image ( std::string filename );

      Image ( unsigned char* data, Cairo::Format format, int width, int height, int stride, bool convert_rgba=false );

      Image ( Cairo::Format format, int width, int height );

      /**
       * Constructor which sets the image to a cairo surface.
       *
       * @param img
       *     The Cairo image surface to be drawn into the canvas.
       */
      Image ( Cairo::RefPtr<Cairo::ImageSurface> img );

      static Image::pointer create( );

      static Image::pointer create ( std::string filename );

      static Image::pointer create ( unsigned char* data, Cairo::Format format, int width, int height, int stride, bool convert_rgba=false );

      static Image::pointer create ( Cairo::Format format, int width, int height );

      /**
       * The create class method is used to create a new instance from
       * a Cairo image surface.
       *
       * @param img
       *     The cairo image surface containing the image.
       * @returns
       *     smart pointer to the new instance
       */
      static Image::pointer create ( Cairo::RefPtr<Cairo::ImageSurface> img );

      /** Destructor */
      virtual ~Image();

      std::string filename() const;

      void set_image ( const std::string& filename );

      void set_image ( unsigned char* data, Cairo::Format format, int width, int height, int stride, bool convert_rgba=false );

      void set_image ( Cairo::Format format, int width, int height );

      /**
       * The set_image method is used to replace the image with the
       * image in a cairo image surface.
       *
       * @param img
       *     The cairo image surface containing the image.
       */
      void set_image ( Cairo::RefPtr<Cairo::ImageSurface> img );

      virtual void draw ( Cairo::RefPtr<Cairo::Context> cairo );

      double width();

      double height();

      void width_height ( double& width, double& height );

      PAPYRUS_CLASS_NAME ( "Image" );

      PAPYRUS_CLONE_METHOD ( Image );

    protected:
      std::string m_filename;
      double m_width, m_height;
      Cairo::RefPtr<Cairo::ImageSurface> m_image;

      void on_image_changed();
  };

}

#endif
