/***************************************************************************
 *   Copyright (C) 2004 by Rick L. Vinyard, Jr.                            *
 *   rvinyard@cs.nmsu.edu                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU Lesser General Public License as        *
 *   published by the Free Software Foundation version 2.1.                *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU Lesser General Public      *
 *   License along with this library; if not, write to the                 *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA              *
 ***************************************************************************/
#ifndef PAPYRUSREGION_H
#define PAPYRUSREGION_H

#include <papyrus/object.h>

#include <cairomm/cairomm.h>

namespace Papyrus {

/**
@author Rick L Vinyard Jr
*/
class Region: public Object {
public:

    Region(double x=0.0, double y=0.0, double w=0.0, double h=0.0);

    virtual ~Region();

    double x() const;
    double y() const;
    double width() const;
    double height() const;

    double xywh(double& x, double& y, double& w, double& h) const;

    double left() const;
    double right() const;
    double top() const;
    double bottom() const;
    void lrtb(double& l, double& r, double& t, double& b) const;

    void center(double& x, double& y) const;


    void set_x(double x);
    void set_y(double y);
    void set_width(double w);
    void set_height(double h);
    void set_xywh(double x, double y, double w, double h);

    bool include(const Region& other);
    bool include(double x, double y);
    bool include_x(double x);
    bool include_y(double y);

    void left_bottom(double& l, double& b) const;
    void right_top(double& r, double& t) const;

    Region& operator=(const Region& other);

    /** true if the regions are identical */
    bool operator==(const Region& other) const;

    bool operator!=(const Region& other) const {
        return !(*this == other);
    }

    /** true if this region is completely contained within the other region */
    bool operator<(const Region& other) const;

    bool operator<=(const Region& other) const;

    /** true of this region is completely outside the other region */
    bool operator>(const Region& other) const;

    bool operator>=(const Region& other) const;

    /** true if (x,y) is an interior point of or on the boundary of this region */
    bool is_inside(double x, double y) const ;

    /** true if (x,y) is an interior point of this region */
    bool is_interior(double x, double y) const ;

    /** true if (x,y) is a boundary point of this region */
    bool is_boundary(double x, double y) const ;

    void transform(const Cairo::Matrix& matrix);

protected:
    double m_x, m_y, m_w, m_h;
};

}

#endif
