/***************************************************************************
 *   Copyright (C) 2004 by Rick L. Vinyard, Jr.                            *
 *   rvinyard@cs.nmsu.edu                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU Lesser General Public License as        *
 *   published by the Free Software Foundation version 2.1.                *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU Lesser General Public      *
 *   License along with this library; if not, write to the                 *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA              *
 ***************************************************************************/
#ifndef PAPYRUSROTATOR_H
#define PAPYRUSROTATOR_H

#include <papyrus/selector.h>

namespace Papyrus
{

  /**
    @author Rick L Vinyard Jr <rvinyard@cs.nmsu.edu>
   */
  class Rotator : public Selector
  {
    public:
      typedef PapyrusSmartPointer<Rotator> pointer;

    Rotator(Group::pointer selection_group = Group::pointer(),
            SelectionMode mode = SELECT_PRESS,
            int selection_depth = 1,
            double radian_interval = 0.0
           );

    Rotator(Group::pointer select_from_group,
            Group::pointer selection_group,
            SelectionMode mode = SELECT_PRESS,
            int selection_depth = 1,
            double radian_interval = 0.0
           );

    static Rotator::pointer create(Group::pointer selection_group = Group::pointer(),
                                   SelectionMode mode = SELECT_PRESS,
                                   int selection_depth = 1,
                                   double radian_interval = 0.0
                                  );

    static Rotator::pointer create(Group::pointer select_from_group,
                                   Group::pointer selection_group,
                                   SelectionMode mode = SELECT_PRESS,
                                   int selection_depth = 1,
                                   double radian_interval = 0.0
                                  );

    virtual ~Rotator();

//     double radian_interval();

//     void set_radian_interval( double radian_interval );

  protected:
    double m_original_position[2], m_centroid[2];
    double m_radian_interval;
    double m_last_angle;

    virtual bool on_motion(const Event::Motion& event);
    virtual bool on_button_press(const Event::ButtonPress& event);

  };

}

#endif
