/***************************************************************************
 *   Copyright (C) 2004 by Rick L. Vinyard, Jr.                            *
 *   rvinyard@cs.nmsu.edu                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU Lesser General Public License as        *
 *   published by the Free Software Foundation version 2.1.                *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU Lesser General Public      *
 *   License along with this library; if not, write to the                 *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA              *
 ***************************************************************************/
#ifndef PAPYRUSTRANSLATOR_H
#define PAPYRUSTRANSLATOR_H

#include <papyrus/selector.h>

namespace Papyrus
{

  /**
    @author Rick L Vinyard Jr <rvinyard@cs.nmsu.edu>
   */
  class Translator : public Selector
  {
    public:
      typedef PapyrusSmartPointer<Translator> pointer;

    Translator(Group::pointer selection_group = Group::pointer(),
               SelectionMode mode = SELECT_PRESS,
               int selection_depth = 1,
               unsigned transforms = TRANSLATE_X|TRANSLATE_Y );

    Translator(Group::pointer select_from_group,
               Group::pointer selection_group,
               SelectionMode mode = SELECT_PRESS,
               int selection_depth = 1,
               unsigned transforms = TRANSLATE_X|TRANSLATE_Y );

    static Translator::pointer create(Group::pointer selection_group = Group::pointer(),
                                      SelectionMode mode = SELECT_PRESS,
                                      int selection_depth = 1,
                                      unsigned transforms = TRANSLATE_X|TRANSLATE_Y );

    static Translator::pointer create(Group::pointer select_from_group,
                                      Group::pointer selection_group,
                                      SelectionMode mode = SELECT_PRESS,
                                      int selection_depth = 1,
                                      unsigned transforms = TRANSLATE_X|TRANSLATE_Y );

    virtual ~Translator();

    unsigned transforms();

    void set_transforms( unsigned transforms );

    void enable_transforms( unsigned transforms );

    void disable_transforms( unsigned transforms );

    /** Gets the current grid size */
    void grid( double& x, double& y );

    /**
     * Sets the grid x and y sizes. If either is <= 0.0 then the
     * grid will be turned off for that dimension.
     */
    void set_grid( double x, double y );

    void set_grid_x( double x );

    void set_grid_y( double y );

  protected:
    double m_original_position[2];
    unsigned m_transforms;
    double m_grid[2];

    virtual bool on_motion(const Event::Motion& event);
    virtual bool on_button_press(const Event::ButtonPress& event);

  };

}

#endif
