/***************************************************************************
*   Copyright (C) 2004 by Rick L. Vinyard, Jr.                            *
*   rvinyard@cs.nmsu.edu                                                  *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU Lesser General Public License as        *
*   published by the Free Software Foundation version 2.1.                *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU Lesser General Public      *
*   License along with this library; if not, write to the                 *
*   Free Software Foundation, Inc.,                                       *
*   51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA              *
***************************************************************************/
#ifndef PAPYRUSGTKUTILITY_H
#define PAPYRUSGTKUTILITY_H

#include <gtkmm.h>
#include <papyrus/renderable.h>

namespace PapyrusGtk {

/**
 * \page guide_pixbuf Gdk::Pixbuf from Papyrus::Canvas
 *
 * Glib::RefPtr<Gdk::Pixbuf> create_pixbuf(Papyrus::Renderable::pointer, int width, int height)
 *
 * Given a Papyrus::Renderable and size as width, height this method will create a Gdk::Pixbuf.
 * This method will not resize the Papyrus::Renderable to fit on the Gdk::Pixbuf. It will simply
 * render directly into the Gdk::Pixbuf.
 *
 * Although the PapyrusGtk::CanvasArea is capable of displaying a Papyrus::Canvas, this utility
 * method is provided for those cases where a Gdk::Pixbuf is needed instead. As an example, one such
 * class present in Gtkmm is Gtk::CellRendererPixbuf.
 *
 * The following contains an example that will add a Papyrus::Group to a Papyrus::Canvas, render
 * the Papyrus::Canvas into a Gdk::Pixbuf, and display the Gdk::Pixbuf inside a Gtk::Image widget.
 *
 * \image html screenshot_pixbuf_from_canvas.png "Screenshot created with code below; Gtk::Image containing Gdk::Pixbuf created with PapyrusGtk::create_pixbuf()"
 *
 * \dontinclude pixbuf.cpp
 * \skip PixbufWindow
 * \until }
 *
 */
Glib::RefPtr<Gdk::Pixbuf> create_pixbuf(Papyrus::Renderable::pointer, int width, int height);

}

#endif
